@@ -62,7 +62,8 @@ typedef enum {
 	GDA_CONNECTION_CANT_LOCK_ERROR,
 	GDA_CONNECTION_TASK_NOT_FOUND_ERROR,
 	GDA_CONNECTION_UNSUPPORTED_THREADS_ERROR,
-	GDA_CONNECTION_CLOSED_ERROR
+	GDA_CONNECTION_CLOSED_ERROR,
+	GDA_CONNECTION_META_DATA_CONTEXT_ERROR
 } GdaConnectionError;
 
 #define GDA_CONNECTION_NONEXIST_DSN_ERROR GDA_CONNECTION_DSN_NOT_FOUND_ERROR
