@@ -138,7 +138,9 @@ gboolean            gda_holder_set_value_to_default    (GdaHolder *holder);
 gboolean            gda_holder_value_is_default        (GdaHolder *holder);
 
 void                gda_holder_force_invalid           (GdaHolder *holder);
+void                gda_holder_force_invalid_e         (GdaHolder *holder, GError *error);
 gboolean            gda_holder_is_valid                (GdaHolder *holder);
+gboolean            gda_holder_is_valid_e              (GdaHolder *holder, GError **error);
 
 
 void                gda_holder_set_not_null            (GdaHolder *holder, gboolean not_null);
@@ -159,7 +161,7 @@ void                gda_holder_set_attribute            (GdaHolder *holder, cons
  * gda_holder_set_attribute_static
  * @holder: a #GdaHolder
  * @attribute: attribute's name
- * @value: a #GValue, or %NULL
+ * @value: (allow-none): a #GValue, or %NULL
  *
  * This function is similar to gda_holder_set_attribute() but for static strings
  */
