@@ -1320,7 +1320,23 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 			}
 		}
 		if (!h) {
-			if (! allow_noparam) {
+			if (allow_noparam) {
+                                /* bind param to NULL */
+				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
+				if (!jexec_res) {
+					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+					if (lerror)
+						gda_connection_event_set_description (event,
+						lerror->message ? lerror->message : _("No detail"));
+					g_propagate_error (error, lerror);
+					break;
+				}
+				gda_value_free (jexec_res);
+                                empty_rs = TRUE;
+                                continue;
+			}
+			else {
 				gchar *str;
 				str = g_strdup_printf (_("Missing parameter '%s' to execute query"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1329,8 +1345,11 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-			}
-			else {
+                        }
+
+		}
+		if (!gda_holder_is_valid (h)) {
+			if (allow_noparam) {
                                 /* bind param to NULL */
 				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
 								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
@@ -1345,11 +1364,8 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 				gda_value_free (jexec_res);
                                 empty_rs = TRUE;
                                 continue;
-                        }
-
-		}
-		if (!gda_holder_is_valid (h)) {
-			if (! allow_noparam) {
+			}
+			else {
 				gchar *str;
 				str = g_strdup_printf (_("Parameter '%s' is invalid"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1358,22 +1374,6 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-			}
-			else {
-                                /* bind param to NULL */
-				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
-				if (!jexec_res) {
-					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-					if (lerror)
-						gda_connection_event_set_description (event,
-						lerror->message ? lerror->message : _("No detail"));
-					g_propagate_error (error, lerror);
-					break;
-				}
-				gda_value_free (jexec_res);
-                                empty_rs = TRUE;
-                                continue;
                         }
 		}
 		else if (gda_holder_value_is_default (h) && !gda_holder_get_value (h)) {
@@ -1409,19 +1409,91 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 
 		/* actual binding using the C API, for parameter at position @i */
 		const GValue *value = gda_holder_get_value (h);
-		jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-						     ps->pstmt_obj, NULL, NULL, &lerror, i, 
-						     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
-		if (!jexec_res) {
-			event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-			if (lerror)
-				gda_connection_event_set_description (event,
-								      lerror->message ? lerror->message : _("No detail"));
+		if (!value || gda_value_is_null (value)) {
+			GdaStatement *rstmt;
+			if (! gda_rewrite_statement_for_null_parameters (stmt, params, &rstmt, error)) {
+				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+								     ps->pstmt_obj, NULL, NULL, &lerror, i, 
+								     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
+				if (!jexec_res) {
+					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+					if (lerror)
+						gda_connection_event_set_description (event,
+										      lerror->message ? lerror->message : _("No detail"));
+					
+					g_propagate_error (error, lerror);
+					break;
+				}
+				gda_value_free (jexec_res);
+			}
+			else if (!rstmt)
+				return NULL;
+			else {
+				_gda_jdbc_release_jenv (jni_detach);
 
-			g_propagate_error (error, lerror);
-			break;
+				/* The strategy here is to execute @rstmt using its prepared
+				 * statement, but with common data from @ps. Beware that
+				 * the @param_ids attribute needs to be retained (i.e. it must not
+				 * be the one copied from @ps) */
+				GObject *obj;
+				GdaJdbcPStmt *tps;
+				GdaPStmt *gtps;
+				GSList *prep_param_ids, *copied_param_ids;
+				if (!gda_jdbc_provider_statement_prepare (provider, cnc,
+									  rstmt, error))
+					return NULL;
+				tps = (GdaJdbcPStmt *)
+					gda_connection_get_prepared_statement (cnc, rstmt);
+				gtps = (GdaPStmt *) tps;
+
+				/* keep @param_ids to avoid being cleared by gda_pstmt_copy_contents() */
+				prep_param_ids = gtps->param_ids;
+				gtps->param_ids = NULL;
+				
+				/* actual copy */
+				gda_pstmt_copy_contents ((GdaPStmt *) ps, (GdaPStmt *) tps);
+
+				/* restore previous @param_ids */
+				copied_param_ids = gtps->param_ids;
+				gtps->param_ids = prep_param_ids;
+
+				/* execute */
+				obj = gda_jdbc_provider_statement_execute (provider, cnc,
+									   rstmt, params,
+									   model_usage,
+									   col_types,
+									   last_inserted_row,
+									   task_id, async_cb,
+									   cb_data, error);
+				/* clear original @param_ids and restore copied one */
+				g_slist_foreach (prep_param_ids, (GFunc) g_free, NULL);
+				g_slist_free (prep_param_ids);
+
+				gtps->param_ids = copied_param_ids;
+
+				/*if (GDA_IS_DATA_MODEL (obj))
+				  gda_data_model_dump ((GdaDataModel*) obj, NULL);*/
+
+				g_object_unref (rstmt);
+				g_object_unref (ps);
+				return obj;
+			}
+		}
+		else {
+			jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+							     ps->pstmt_obj, NULL, NULL, &lerror, i, 
+							     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
+			if (!jexec_res) {
+				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+				if (lerror)
+					gda_connection_event_set_description (event,
+									      lerror->message ? lerror->message : _("No detail"));
+				
+				g_propagate_error (error, lerror);
+				break;
+			}
+			gda_value_free (jexec_res);
 		}
-		gda_value_free (jexec_res);
 	}
 		
 	if (event) {
@@ -1762,8 +1834,8 @@ gda_jdbc_provider_new (const gchar *jdbc_driver, GError **error)
 	g_return_val_if_fail (jdbc_driver, NULL);
 
 	if (!_jdbc_provider_java_vm) {
-		g_set_error (error, 0, 0, "%s", 
-			     "No JVM runtime identified (this should not happen at this point)!");
+		g_set_error (error, GDA_SERVER_PROVIDER_ERROR, GDA_SERVER_PROVIDER_INTERNAL_ERROR,
+			     "%s", "No JVM runtime identified (this should not happen at this point)!");
 		return NULL;
 	}
 
