@@ -1512,12 +1512,11 @@ gda_postgres_provider_statement_prepare (GdaServerProvider *provider, GdaConnect
 	/* actually prepare statement */
 	PGresult *pg_res;
 	gchar *prep_stm_name;
-	GdaConnectionEvent *event = NULL;
 
 	prep_stm_name = g_strdup_printf ("psc%d", counter ++);
 	pg_res = PQprepare (cdata->pconn, prep_stm_name, sql, 0, NULL);
 	if (!pg_res || (PQresultStatus (pg_res) != PGRES_COMMAND_OK)) {
-		event = _gda_postgres_make_error (cnc, cdata->pconn, pg_res, error);
+		_gda_postgres_make_error (cnc, cdata->pconn, pg_res, error);
 		g_free (prep_stm_name);
 		if (pg_res)
 			PQclear (pg_res);
@@ -1594,12 +1593,11 @@ prepare_stmt_simple (PostgresConnectionData *cdata, const gchar *sql, GError **e
 	static guint counter = 0; /* each prepared statement MUST have a unique name, ensured with this counter */
 	PGresult *pg_res;
 	gchar *prep_stm_name;
-	GdaConnectionEvent *event = NULL;
 
 	prep_stm_name = g_strdup_printf ("pss%d", counter++);
 	pg_res = PQprepare (cdata->pconn, prep_stm_name, sql, 0, NULL);
 	if (!pg_res || (PQresultStatus (pg_res) != PGRES_COMMAND_OK)) {
-		event = _gda_postgres_make_error (cdata->cnc, cdata->pconn, pg_res, error);
+		_gda_postgres_make_error (cdata->cnc, cdata->pconn, pg_res, error);
 		g_free (prep_stm_name);
 		if (pg_res)
 			PQclear (pg_res);
@@ -2017,13 +2015,39 @@ gda_postgres_provider_statement_execute (GdaServerProvider *provider, GdaConnect
 			else if (!rstmt)
 				return NULL;
 			else {
-				GObject *obj;
 				params_freev (param_values, param_mem, nb_params);
 				g_free (param_lengths);
 				g_free (param_formats);
 				if (transaction_started)
 					gda_connection_rollback_transaction (cnc, NULL, NULL);
 
+				/* The strategy here is to execute @rstmt using its prepared
+				 * statement, but with common data from @ps. Beware that
+				 * the @param_ids attribute needs to be retained (i.e. it must not
+				 * be the one copied from @ps) */
+				GObject *obj;
+				GdaPostgresPStmt *tps;
+				GdaPStmt *gtps;
+				GSList *prep_param_ids, *copied_param_ids;
+				if (!gda_postgres_provider_statement_prepare (provider, cnc,
+									      rstmt, error))
+					return NULL;
+				tps = (GdaPostgresPStmt *)
+					gda_connection_get_prepared_statement (cnc, rstmt);
+				gtps = (GdaPStmt *) tps;
+
+				/* keep @param_ids to avoid being cleared by gda_pstmt_copy_contents() */
+				prep_param_ids = gtps->param_ids;
+				gtps->param_ids = NULL;
+				
+				/* actual copy */
+				gda_pstmt_copy_contents ((GdaPStmt *) ps, (GdaPStmt *) tps);
+
+				/* restore previous @param_ids */
+				copied_param_ids = gtps->param_ids;
+				gtps->param_ids = prep_param_ids;
+
+				/* execute */
 				obj = gda_postgres_provider_statement_execute (provider, cnc,
 									       rstmt, params,
 									       model_usage,
@@ -2031,15 +2055,16 @@ gda_postgres_provider_statement_execute (GdaServerProvider *provider, GdaConnect
 									       last_inserted_row,
 									       task_id, async_cb,
 									       cb_data, error);
+				/* clear original @param_ids and restore copied one */
+				g_slist_foreach (prep_param_ids, (GFunc) g_free, NULL);
+				g_slist_free (prep_param_ids);
+
+				gtps->param_ids = copied_param_ids;
+
+				/*if (GDA_IS_DATA_MODEL (obj))
+				  gda_data_model_dump ((GdaDataModel*) obj, NULL);*/
+
 				g_object_unref (rstmt);
-				if (GDA_IS_DATA_SELECT (obj)) {
-					GdaPStmt *pstmt;
-					g_object_get (obj, "prepared-stmt", &pstmt, NULL);
-					if (pstmt) {
-						gda_pstmt_set_gda_statement (pstmt, stmt);
-						g_object_unref (pstmt);
-					}
-				}
 				return obj;
 			}
 		}
