@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 Vivien Malerba <malerba@gnome-db.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
 #include <libgda-ui/libgda-ui.h>
 #include "../tests/data-model-errors.h"
 
@@ -26,7 +44,7 @@ main (int argc, char *argv[])
 				  window);
 	gtk_container_set_border_width (GTK_CONTAINER (window), 10);
 
-	vbox = gtk_vbox_new (FALSE, 5);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
 	gtk_container_add (GTK_CONTAINER (window), vbox);
 
 	/* main form to list customers */
