@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,16 +37,24 @@ typedef struct _DataManagerPerspectivePriv DataManagerPerspectivePriv;
 /* struct for the object's data */
 struct _DataManagerPerspective
 {
-	GtkVBox                     object;
+	GtkBox                     object;
 	DataManagerPerspectivePriv *priv;
 };
 
 /* struct for the object's class */
 struct _DataManagerPerspectiveClass
 {
-	GtkVBoxClass                parent_class;
+	GtkBoxClass                parent_class;
 };
 
+/**
+ * SECTION:data-manager-perspective
+ * @short_description: Perspective to manipulate data contained in the database
+ * @title: Data Manager perspective
+ * @stability: Stable
+ * @see_also:
+ */
+
 GType                data_manager_perspective_get_type (void) G_GNUC_CONST;
 BrowserPerspective  *data_manager_perspective_new      (BrowserWindow *bwin);
 void                 data_manager_perspective_new_tab  (DataManagerPerspective *dmp, const gchar *xml_spec);
