@@ -117,6 +117,8 @@ ldap_classes_page_init (LdapClassesPage *ebrowser, G_GNUC_UNUSED LdapClassesPage
 	ebrowser->priv->history_items = g_array_new (FALSE, FALSE, sizeof (HistoryItem*));
 	ebrowser->priv->history_max_len = 20;
 	ebrowser->priv->add_hist_item = TRUE;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (ebrowser), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -171,7 +173,7 @@ ldap_classes_page_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "LdapClassesPage", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "LdapClassesPage", &info, 0);
 		g_type_add_interface_static (type, BROWSER_PAGE_TYPE, &page_info);
 	}
 	return type;
@@ -333,7 +335,7 @@ selection_changed_cb (GtkTreeSelection *sel, LdapClassesPage *ebrowser)
 }
 
 static void
-open_classname_requested_cb (ClassProperties *eprop, const gchar *classname, LdapClassesPage *ebrowser)
+open_classname_requested_cb (G_GNUC_UNUSED ClassProperties *eprop, const gchar *classname, LdapClassesPage *ebrowser)
 {
 	ldap_classes_page_set_current_class (ebrowser, classname);
 }
@@ -367,14 +369,14 @@ ldap_classes_page_new (BrowserConnection *bcnc, const gchar *classname)
 
 	/* VPaned widget */
 	GtkWidget *hp;
-	hp = gtk_hpaned_new ();
+	hp = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (ebrowser), hp, TRUE, TRUE, 0);
 
 	/* tree */
 	GtkWidget *vbox, *hview, *sw;
 	gfloat yalign;
 
-	vbox = gtk_vbox_new (FALSE, FALSE);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, FALSE);
 	gtk_paned_add1 (GTK_PANED (hp), vbox);
 	
 	str = g_strdup_printf ("<b>%s:</b>", _("LDAP classes"));
@@ -401,7 +403,7 @@ ldap_classes_page_new (BrowserConnection *bcnc, const gchar *classname)
 			  G_CALLBACK (selection_changed_cb), ebrowser);
 
 	/* details */
-	vbox = gtk_vbox_new (FALSE, FALSE);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, FALSE);
 	gtk_paned_add2 (GTK_PANED (hp), vbox);
 
 	str = g_strdup_printf ("<b>%s:</b>", _("LDAP class's properties"));
@@ -459,9 +461,8 @@ action_add_to_fav_cb (G_GNUC_UNUSED GtkAction *action, LdapClassesPage *ebrowser
 	BrowserFavorites *bfav;
         BrowserFavoritesAttributes fav;
         GError *error = NULL;
-	const gchar *tmp;
 
-	tmp = classes_view_get_current_class (CLASSES_VIEW (ebrowser->priv->classes_view));
+	classes_view_get_current_class (CLASSES_VIEW (ebrowser->priv->classes_view));
         memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
         fav.id = -1;
         fav.type = BROWSER_FAVORITES_LDAP_CLASS;
@@ -610,11 +611,9 @@ ldap_classes_page_page_get_actions_ui (G_GNUC_UNUSED BrowserPage *page)
 static GtkWidget *
 ldap_classes_page_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button)
 {
-	LdapClassesPage *ebrowser;
 	const gchar *tab_name;
 	GdkPixbuf *classes_pixbuf;
 
-	ebrowser = LDAP_CLASSES_PAGE (page);
 	classes_pixbuf = browser_get_pixbuf_icon (BROWSER_ICON_LDAP_CLASS_STRUCTURAL);
 	tab_name = _("LDAP classes");
 	return browser_make_tab_label_with_pixbuf (tab_name,
