@@ -1,23 +1,19 @@
 /*
- * Copyright (C) 2011 The GNOME Foundation
+ * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -110,6 +106,8 @@ ldap_favorite_selector_init (LdapFavoriteSelector *fsel, G_GNUC_UNUSED LdapFavor
 	fsel->priv = g_new0 (LdapFavoriteSelectorPrivate, 1);
 	fsel->priv->idle_update_favorites = 0;
 	fsel->priv->prop_save_timeout = 0;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (fsel), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -163,7 +161,7 @@ ldap_favorite_selector_get_type (void)
 			(GInstanceInitFunc) ldap_favorite_selector_init,
 			0
 		};
-		type = g_type_register_static (GTK_TYPE_VBOX, "LdapFavoriteSelector",
+		type = g_type_register_static (GTK_TYPE_BOX, "LdapFavoriteSelector",
 					       &info, 0);
 	}
 	return type;
@@ -197,7 +195,7 @@ favorite_delete_selected (LdapFavoriteSelector *fsel)
 }
 
 static gboolean
-key_press_event_cb (GtkTreeView *treeview, GdkEventKey *event, LdapFavoriteSelector *fsel)
+key_press_event_cb (G_GNUC_UNUSED GtkTreeView *treeview, GdkEventKey *event, LdapFavoriteSelector *fsel)
 {
 	if (event->keyval == GDK_KEY_Delete) {
 		favorite_delete_selected (fsel);
@@ -278,7 +276,7 @@ properties_activated_cb (GtkMenuItem *mitem, LdapFavoriteSelector *fsel)
 		gfloat align;
 		
 		pcont = popup_container_new (GTK_WIDGET (mitem));
-		vbox = gtk_vbox_new (FALSE, 0);
+		vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 		gtk_container_add (GTK_CONTAINER (pcont), vbox);
 		
 		label = gtk_label_new ("");
@@ -289,7 +287,7 @@ properties_activated_cb (GtkMenuItem *mitem, LdapFavoriteSelector *fsel)
 		gtk_misc_set_alignment (GTK_MISC (label), 0., align);
 		gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 		
-		hbox = gtk_hbox_new (FALSE, 0); /* HIG */
+		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0); /* HIG */
 		gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 5);
 		label = gtk_label_new ("      ");
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
