@@ -113,6 +113,8 @@ static void
 table_info_init (TableInfo *tinfo, G_GNUC_UNUSED TableInfoClass *klass)
 {
 	tinfo->priv = g_new0 (TableInfoPrivate, 1);
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (tinfo), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -167,7 +169,7 @@ table_info_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "TableInfo", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "TableInfo", &info, 0);
 		g_type_add_interface_static (type, BROWSER_PAGE_TYPE, &page_info);
 	}
 	return type;
@@ -347,7 +349,7 @@ table_info_new (BrowserConnection *bcnc,
 	/* "table not found" error page */
 	GtkWidget *image, *hbox;
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (""), TRUE, TRUE, 0);
 	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 10);
